

//  ######
//  AI Builder v2.0
//  DataRecordOperations class.
//  By Richard John Sproston.
//  E-mail richard.sproston@gmail.com || lucky_jackpot@hotmail.com
//  Copyright () 2004/2005, Richard John Sproston.
//  All Rights Reserved.
//  Sept-2004
//  ######


package bin;


    // Import system class libraries for application
  import java.io.*;


/**
 * DataRecordOperations Class
 * <p>
 * This class is responsible for recording the various data
 * operations, such as writing to files.
 * </p>
 * <br />
 * <br />
 * <br />
 *
 * version 0.3 - Initial Release <br />
 * <br />
 * <br />
 *
 * v0.4 - UPDATE <br />
 * Added the "readFile() method" for loading
 * AI files into AI Builder.
 * <br />
 * <br />
 *
 * v0.5 - UPDATE <br />
 * Provided improved javadoc commentary and a tweak for the
 * "writeFile()" method.
 *
 * <br />
 * <br />
 *
 * @author Richard John Sproston
 * [ <a href="mailto:richard.sproston@gmail.com">richard.sproston@gmail.com</a> ||
 * <a href="mailto:lucky_jackpot@hotmail.com">lucky_jackpot@hotmail.com</a> ]
 *
 * @version 0.5 - Improved javadoc, class layout and a couple of small tweaks.
 *  Nothing major.
 *
 */
public class DataRecordOperations {


//=========================================================


    //////////////////////////
    //  INSTANCE VARIABLES  //
    //////////////////////////


        /** The String placeholder for an entire AI file that
            is read into memory. */
    private String textDocument;


//=========================================================


    ////////////////////
    //  CONSTRUCTORS  //
    ////////////////////


    /**
     * Default Constructor for class, with no parameters
     */
    public DataRecordOperations()
    {}


//=========================================================


    //////////////////////
    //  ACCESS SETTERS  //
    //////////////////////


    /**
     * After having read the contents of a file into memory,
     * this method is responsible for creating a String
     * variable to set (and hold) the contents.
     *
     * @param textDocument The String that is to set and hold
     *  the read input AI file.
     *
     */
    public void setTextDocument (String textDocument) {
        this.textDocument = textDocument;
    }


//=========================================================


    ////////////////////////
    //  ACCESS MODIFIERS  //
    ////////////////////////


    /**
     * This method is used to retrieve the placeholder String
     * that contains an AI file that was read into memory.
     *
     * @return The contents of an AI file (stored as a String).
     *
     */
    public String getTextDocument() {
        return textDocument;
    }


//=========================================================


    ///////////////
    //  METHODS  //
    ///////////////


    /**
     * This method is used to store (write) AI preview code to a file on disk.
     * This is used either the first time a document is created
     * (and no other files of the same name exist) or a "New Document" is
     * created (with a document of the same name existing).
     * [Determinations based on user-interactions from GUIFramework class.]
     *
     * @throws IOException To be handled by GUIFramework class.
     *
     * @param document The text that is displayed in the generated
     *  AI file preview text-area.
     *
     */
    public void writeFile (File fileObj, String document) throws IOException {
        FileWriter fileWrite = new FileWriter (fileObj, true);
        BufferedWriter bufferWriter = new BufferedWriter (fileWrite);

        bufferWriter.write (document);  // write the AI text for the file

            // Release open resources for efficiency...
        bufferWriter.flush();       // Flush IO Stream...
        bufferWriter.close();       // ...and then close the IO Stream...
    }


    /**
     * This method is used to read the contents of an AI file and store
     * the information as a String.  It uses a <code>BufferedReader</code>
     * to read through the plain-text file, compiling all the String
     * information it requires to "rebuild" the AI file, verbatim, and
     * uses the <code>"setTextDocument (<i>arg_value</i>)" method to
     * store the String.
     *
     * @param fileObj The File object that refers to a file for reading.
     *
     */
    public void readFile (File fileObj) throws IOException {
        FileReader fileReader = new FileReader (fileObj);
        BufferedReader bufferReader = new BufferedReader (fileReader);

        String textLine = null;
        String concat = new String();
        while ( (textLine = bufferReader.readLine() ) != null) {
            concat += textLine + "\n";
        }

        setTextDocument (concat);
        if (GlobalConstants.VERBOSE_DEBUG)
            System.out.println (concat);

        bufferReader.close();
    }


//=========================================================


}   /*  End Of File  */