

//  ######
//  AI Builder v2.0
//  InstinctException class.
//  By Richard John Sproston.
//  E-mail richard.sproston@gmail.com || lucky_jackpot@hotmail.com
//  Copyright () 2004/2005, Richard John Sproston.
//  All Rights Reserved.
//  Jan-2005
//  ######


package bin;


/**
 * InstinctException Class
 * <p>
 * This class is used to handle any exceptions during parsing
 * of any files that are generated/loaded into AI Builder.
 * <p>
 *
 * @author Richard John Sproston
 * [ <a href="mailto:richard.sproston@gmail.com">richard.sproston@gmail.com</a> ||
 * <a href="mailto:lucky_jackpot@hotmail.com">lucky_jackpot@hotmail.com</a> ]
 *
 * @version 0.1 - Initial Release
 *
 */
public class InstinctException extends Exception {


//=========================================================


    ////////////////////
    //  CONSTRUCTORS  //
    ////////////////////


    /**
     * Default Constructor for this class with no parameters.
     */
    public InstinctException() {
        this ("");
    }


    /**
     * Default Constructor for class with 1 parameter.
     *
     * @param errorMessage The error message to display.
     *
     */
    public InstinctException (String errorMessage) {
        super (errorMessage);
    }


    /**
     * Default Constructor for class, with 2 parameters.
     * <p>
     * This exception method is triggered by the Parser class, if it
     * encounters any white space <i>before</i> an AI instinct
     * (usually in an imported file).
     * </p>
     * <p>
     * With AI Builder, the superclass is <i>GUIFramework</i>
     * (as may be witnessed in its attempt to "try/catch" this
     * type of exception).
     * </p>
     *
     * @param errorMessage This is the error String that will be passed
     *  "onwards and upwards" to the superclass.
     *
     */
    public InstinctException (String errorMessage, int lineNumber) {
            // A call to super MUST be the first statement!
        super ("Error parsing file (line " +
            lineNumber + "):\n" + errorMessage);
    }


    /**
     * Default Constructor for class, with 4 parameters.
     * <p>
     * This exception method is triggered by the Parser class, if it
     * encounters a syntax error with a particular AI instinct
     * (this will <i>always</i> be due to an invalid number of parameters
     * for the instinct in question).
     * </p>
     * <p>
     * With AI Builder, the superclass is <i>GUIFramework</i>
     * (as may be witnessed in its attempt to "try/catch" this
     * type of exception).
     * </p>
     *
     * @param errorMessage The descriptive error message that is
     *  to be displayed.
     * @param lineNumber The particular line number where the
     *  parsing error occurred.  Useful for JK editor debugging.
     * @param numParams This informs the JK editor how many parameters
     *  are expected for this instinct.
     * @param currentInstinctParams This details the parameters that the
     *  Instinct <i>expected</i> to find (but obviously didn't).
     *
     */
    public InstinctException (
    String errorMessage, int lineNumber, int numParams,
    String currentInstinctParams) {
        super ( "Error parsing file (line " + lineNumber + "):\n" +
                errorMessage +
                "  This instinct requires " + numParams + " parameters. \n" +
                "Instinct Syntax: \n" + currentInstinctParams
              );
    }


//=========================================================


}   /* End Of File  */