

//  ######
//  AI Builder v2.0
//  OpenFileExtensionFilter class.
//  By Richard John Sproston.
//  E-mail richard.sproston@gmail.com || lucky_jackpot@hotmail.com
//  Copyright () 2004/2005, Richard John Sproston.
//  All Rights Reserved.
//  Jan-2005
//  ######


package bin;


    // Import system class libraries for application
  import javax.swing.filechooser.FileFilter;
  import java.io.File;
  import java.io.*;


/**
 * "Open File" Extension Filter Class
 * <p>
 * Set-up an extension filter for files, when prompted with "Open" dialogs.
 * </p>
 *
 * @author Richard John Sproston
 * [ <a href="mailto:richard.sproston@gmail.com">richard.sproston@gmail.com</a> ||
 * <a href="mailto:lucky_jackpot@hotmail.com">lucky_jackpot@hotmail.com</a> ]
 *
 * @version 0.1 - Initial Release
 *
 */
public class OpenFileExtensionFilter extends FileFilter {


//=========================================================


    //////////////////////////
    //  INSTANCE VARIABLES  //
    //////////////////////////


        /** The file-type description. */
    private String description;

        /* The file extension to manage "easy"
            <code>(*.ai0)</code> difficulty level. */
    private String extensionEasy;

        /* The file extension to manage "medium"
            <code>(*.ai)</code> difficulty level. */
    private String extensionMedium;

        /* The file extension to manage "hard"
            <code>(*.ai2)</code> difficulty level. */
    private String extensionHard;


//=========================================================


    ////////////////////
    //  CONSTRUCTORS  //
    ////////////////////


    /**
     * Default Constructor for class, with 4 parameters.
     *
     * This is used for the "Open AI File" Dialogue.
     * Set the valid filetypes to be made viewable when searching
     * for files to import into AI Builder.
     *
     * @param ext0 This is used to set a String data-type
     *  as a FileFilter extension.
     * @param ext1 This is used to set a String data-type
     *  as a FileFilter extension.
     * @param ext2 This is used to set a String data-type
     *  as a FileFilter extension.
     * @param desc This is used to provide a String description
     *  of the file extension.
     *
     */
    public OpenFileExtensionFilter (
    String ext0, String ext1, String ext2, String desc) {
        extensionEasy = ext0;
        extensionMedium = ext1;
        extensionHard = ext2;
        description = desc;
    }


//=========================================================


    ///////////////
    //  METHODS  //
    ///////////////


    /**
     * This method returns a boolean value, depending on whether the
     * "file" is successfully accepted by the application as being of
     * the correct data-type.
     *
     * @param file The File object to be checked for a comparison.
     *
     * @return The boolean value returned, depending on whether the
     *  "file" to be accepted is a directory or whether the file ends
     *  with the appropriate extension.
     *
     */
    public boolean accept (File file) {
        return (file.isDirectory() ||
                  file.getName().toLowerCase().endsWith (extensionEasy) ||
                  file.getName().toLowerCase().endsWith (extensionMedium) ||
                  file.getName().toLowerCase().endsWith (extensionHard)
                 );
    }


    /**
     * This method returns the String description for use in
     * manipulating the constructor's value for this variable.
     *
     * @return The String value/content of the variable, for
     *  manipulation in the class's constructor (2 params).
     *
     */
    public String getDescription() {
        return description;
    }


//=========================================================


}   /* End Of File  */